@@ -8,8 +8,9 @@ from .template import Imports, ImportsListroutes, ImportsController, ImportsSche
 
 
 def read_route_list():
-    with open(r'./core/colubrid/modules/routestructure/routestructure.py', 'w') as fp:
-        return ast.literal_eval(fp.read())
+    with open(r'./core/colubrid/modules/routestructure/routestructure.py', 'r') as f2:
+        data = f2.read()
+        return ast.literal_eval(data)
 
 def migrate():
     subprocess.run(['alembic', 'upgrade', 'head'])
@@ -19,7 +20,7 @@ def makemigration(namemigration):
 
 def updateListRute(listRoutes):
     with open(r'./core/colubrid/modules/routestructure/routestructure.py', 'w') as fp:
-        fp.write("%s\n" % "routes_list = [")
+        fp.write("%s\n" % "[")
         for item in listRoutes:
             fp.write("\"%s\",\n" % item)
         fp.write("%s\n" % "]")
